==> myfaces-core-assembly-2.0.25-src.zip: myfaces-core-module-2.0.25/impl/src/test/java/org/apache/myfaces/view/facelets/tag/composite/CompositeTestComponent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.view.facelets.tag.composite;

import javax.faces.component.UINamingContainer;
import javax.faces.event.ComponentSystemEvent;

public class CompositeTestComponent extends UINamingContainer
{

    public String getJavaProperty()
    {
        return (String) getStateHelper().eval(PropertyKeys.javaProperty);
    }

    public void setJavaProperty(String javaProperty)
    {
        getStateHelper().put(PropertyKeys.javaProperty, javaProperty);
    }
    
    public void postAddToViewCallback(ComponentSystemEvent event)
    {
        getAttributes().put("postAddToViewCallback", true);
    }
    
    public void preRenderViewCallback(ComponentSystemEvent event)
    {
        getAttributes().put("preRenderViewCallback", true);
    }
    
    protected enum PropertyKeys
    {
        javaProperty
    }
}

==> myfaces-core-assembly-2.3.9-src.zip: myfaces-core-module-2.3.9/impl/src/test/java/org/apache/myfaces/view/facelets/tag/composite/CompositeTestComponent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.view.facelets.tag.composite;

import javax.faces.component.UINamingContainer;
import javax.faces.event.ComponentSystemEvent;

public class CompositeTestComponent extends UINamingContainer
{

    public String getJavaProperty()
    {
        return (String) getStateHelper().eval(PropertyKeys.javaProperty);
    }

    public void setJavaProperty(String javaProperty)
    {
        getStateHelper().put(PropertyKeys.javaProperty, javaProperty);
    }
    
    public void postAddToViewCallback(ComponentSystemEvent event)
    {
        getAttributes().put("postAddToViewCallback", true);
    }
    
    public void preRenderViewCallback(ComponentSystemEvent event)
    {
        getAttributes().put("preRenderViewCallback", true);
    }
    
    public void postRenderViewCallback(ComponentSystemEvent event)
    {
        getAttributes().put("postRenderViewCallback", true);
    }
    
    protected enum PropertyKeys
    {
        javaProperty
    }
}
